; Original MOD file: monkey.mod
; Original MOD name: "monkey island       "
; ASM file created by MOD2PSG V1.2 by Martin Konrad (mkon@gmx.de)
; Command line options: -nf 2 

; Constants
RAM_START = $C000

; PSGMOD variables
; (You can place these variables anywhere in RAM.)
PSGMOD_SONG_POSITION    = RAM_START
PSGMOD_PATTERN_POSITION = RAM_START + 1
PSGMOD_PATTERN_ADDRESS  = RAM_START + 2
PSGMOD_CURRENT_SPEED    = RAM_START + 4
PSGMOD_SPEED_COUNTER    = RAM_START + 5
PSGMOD_SONG_START       = RAM_START + 6
PSGMOD_VOL0             = RAM_START + 8
PSGMOD_VOL1             = RAM_START + 9
PSGMOD_VOL2             = RAM_START + 10
PSGMOD_VOL3             = RAM_START + 11
; Misc variables
VBLANK_DONE_FLAG        = RAM_START + 12

;==========================================
;=               Start code               =
;==========================================
.org $0000
  di
  im 1
  ld sp, $dff0
  jr START
;-------------------
; VBlank IRQ handler
.org $38
  exx
  ex af, af'
  in a, ($BF)

  ld hl, VBLANK_DONE_FLAG
  inc (HL)

  exx
  ex af, af'
  ei
  reti
;-------------------
; NMI
.org $66
  retn
;-------------------
START:
  call SETUP_FRAMES
  call SET_VDP_REGS_TABLE

;==========================================
;=               Song start               =
;==========================================
    ld hl, PSGMOD_SONG
  call PSGMOD_INITIATE_NEW_SONG
  ei
SONG_LOOP:
    ld d, 1
  call VWAIT

  call PSGMOD_PLAY_NEXT_NOTE

  jr SONG_LOOP
;==========================================
;=              Program end               =
;==========================================

;==========================================
;=            PSG MOD routines            =
;==========================================
; INPUT: HL = address of song
PSGMOD_INITIATE_NEW_SONG:
  ld a, 0
  ld (PSGMOD_SONG_POSITION), a
  ld a, 64
  ld (PSGMOD_PATTERN_POSITION), a
  ld a, 6
  ld (PSGMOD_CURRENT_SPEED), a
  ld (PSGMOD_SPEED_COUNTER), a
  ld a, 15
  ld (PSGMOD_VOL0), a
  ld (PSGMOD_VOL1), a
  ld (PSGMOD_VOL2), a
  ld (PSGMOD_VOL3), a
  ld a, l
  ld (PSGMOD_SONG_START), a
  ld a, h
  ld (PSGMOD_SONG_START + 1), a
  ld ix, (PSGMOD_SONG_START)
  ld a, (IX)
  ld l, a
  ld h, 0
  call HL_512
  ld bc, 128
  add hl, bc
  ld bc, (PSGMOD_SONG_START)
  add hl, bc
  ld a, l
  ld (PSGMOD_PATTERN_ADDRESS), a
  ld a, h
  ld (PSGMOD_PATTERN_ADDRESS+1), a
  ret

PSGMOD_PLAY_NEXT_NOTE:
  ld hl, PSGMOD_SPEED_COUNTER
  dec (HL)
  ret NZ

; Channel 0
    ld ix, (PSGMOD_PATTERN_ADDRESS)
    ld d, 144
    ld hl, PSGMOD_VOL0
  call PSGMOD_SET_VOLUME
    ld d, 128
  call PSGMOD_SET_FREQUENCY

; Channel 1
    ld ix, (PSGMOD_PATTERN_ADDRESS)
    inc ix
    inc ix
    ld d, 176
    ld hl, PSGMOD_VOL1
  call PSGMOD_SET_VOLUME
    ld d, 160
  call PSGMOD_SET_FREQUENCY

; Channel 2
    ld ix, (PSGMOD_PATTERN_ADDRESS)
    inc ix
    inc ix
    inc ix
    inc ix
    ld d, 208
    ld hl, PSGMOD_VOL2
  call PSGMOD_SET_VOLUME
    ld d, 192
  call PSGMOD_SET_FREQUENCY

; Channel 3
  ld hl, (PSGMOD_PATTERN_ADDRESS)
  ld bc, 6
  add hl, bc
  ld b, (HL)

; Set volume of channel 3
  ld a, b
  and 15
  add a, 240
  out ($7F), a

; Set frequeny of channel 3
  ld a, b
  srl a
  srl a
  srl a
  srl a
  add a, 228
  out ($7F), a

; Set speed
  ld hl, (PSGMOD_PATTERN_ADDRESS)
  ld bc, 7
  add hl, bc
  ld c, (HL)
  ld a, c
  and 128
  jr Z, PSGMOD_SET_SPEED
  ld a, 1
  ld (PSGMOD_PATTERN_POSITION), a
PSGMOD_SET_SPEED:
  ld a, c
  and 127
  ld (PSGMOD_CURRENT_SPEED), a
PSGMOD_DONT_SET_SPEED:
  ld a, (PSGMOD_CURRENT_SPEED)
  ld (PSGMOD_SPEED_COUNTER), a

; Next note
  ld hl, (PSGMOD_PATTERN_ADDRESS)
  ld bc, 8
  add hl, bc
  ld (PSGMOD_PATTERN_ADDRESS), hl

  ld hl, PSGMOD_PATTERN_POSITION
  dec (HL)
  ret NZ
  ld a, 64
  ld (PSGMOD_PATTERN_POSITION), a
  ld hl, PSGMOD_SONG_POSITION
  inc (HL)

  call PSGMOD_GET_PATTERN_NUMBER
  bit 7, d
  jr Z, PSGMOD_END_NOT_REACHED

  ld a, d
  and 127
  ld (PSGMOD_SONG_POSITION), a
  call PSGMOD_GET_PATTERN_NUMBER
PSGMOD_END_NOT_REACHED:
  ld h, 0
  ld l, d
  call HL_512
  ld bc, 128
  add hl, bc
  ld bc, (PSGMOD_SONG_START)
  add hl, bc
  ld a, l
  ld (PSGMOD_PATTERN_ADDRESS), a
  ld a, h
  ld (PSGMOD_PATTERN_ADDRESS+1), a
  ret

;==========================================
;=       PSG MOD internal routines        =
;==========================================
PSGMOD_SET_VOLUME:
  ld a, (IX)
  and 15
  cp 15
  jr Z, PSGMOD_FADE_VOL
  ld (HL), a
  add a, d
  out ($7F), a
  ret
PSGMOD_FADE_VOL:
  ld a, (HL)
  cp 15
  ret Z
  inc a
  ld (HL), a
  add a, d
  out ($7F), a
  ret
PSGMOD_SET_FREQUENCY:
  ld a, (IX)
  and 15
  cp 15
  ret Z
  ld a, (IX)
  srl a
  srl a
  srl a
  srl a
  add a, d
  out ($7F), a
  inc ix
  ld a, (IX)
  out ($7F), a
  ret

PSGMOD_GET_PATTERN_NUMBER:
  ld a, (PSGMOD_SONG_POSITION)
  ld hl, (PSGMOD_SONG_START)
  ld c, a
  ld b, 0
  add hl, bc
  ld d, (HL)
  ret

;==========================================
;=             Misc routines              =
;==========================================
HL_512:
  add hl, hl
  add hl, hl
  add hl, hl
  add hl, hl
  add hl, hl
  add hl, hl
  add hl, hl
  add hl, hl
  add hl, hl
  ret

VWAIT:
  ld a, 0
  ld (VBLANK_DONE_FLAG), a
VWAIT_LOOP:
  ld a, (VBLANK_DONE_FLAG)
  cp d
  ret Z
  jr VWAIT_LOOP

SETUP_FRAMES:
  ld a, 0
  ld ($FFFC), a
  ld ($FFFD), a
  ld a, 1
  ld ($FFFE), a
  ld a, 2
  ld ($FFFF), a
  ret

SET_VDP_REGS_TABLE:
  ld hl, VDP_REGS_TABLE
  ld b, $0f
  ld c, $80
VDP_REGS_LOOP:
  ld a, (HL)
  inc hl
  out ($bf), a
  ld a, c
  inc c
  out ($bf), a
  dec b
  jr NZ, VDP_REGS_LOOP
  ret

VDP_REGS_TABLE:
   .db $06, $60, $FF, $FF, $FF, $FF, $00, $00, $00, $00, $FF, $00, $00, $00, $00, $00

;==========================================
;=               Song data                =
;==========================================

PSGMOD_SONG:

PSGMOD_PATTERN_ORDER:
.db 0,1,2,3,4,5,6,7
.db 8,9,10,11,12,13,14,5
.db 15,16,17,18,19,20,21,22
.db 23,18,19,20,21,22,23,24
.db 25,26,27,28,29,26,27,28
.db 29,30,128,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0

PSGMOD_PATTERN_DATA:
; PATTERN 0:
.dw 15,7572,15,1792,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,1888,1551,15,15,2512,1551,
.dw 15,15,3184,1551,15,15,3360,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,2319,15,15,15,2319,
.dw 15,15,4256,1551,15,15,15,1551,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,3776,1551,15,15,15,1551,
.dw 15,15,15,1295,15,15,15,1295,
.dw 15,15,3360,1551,15,15,15,1551,
.dw 15,15,15,1551,15,15,15,1551,
.dw 15,15,4256,1551,15,15,15,1551,
.dw 15,15,15,1295,15,15,15,1295,
.dw 15,15,3776,1551,15,15,15,1551,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,5056,5391,15,15,15,5391,
.dw 15,15,15,5391,15,15,3188,5391,
; PATTERN 1:
.dw 15,6372,2836,2831,15,15,15,2831,
.dw 6372,15,2514,2575,15,15,15,2575,
.dw 6374,15,15,2575,6372,15,15,1551,
.dw 15,15,15,1551,6370,15,15,2575,
.dw 15,15,15,2575,6370,15,15,3087,
.dw 15,15,15,3087,3572,15,15,2575,
.dw 15,15,15,2575,3572,15,15,2575,
.dw 3570,15,15,1551,15,15,15,1551,
.dw 3570,5668,8516,2575,15,15,15,2575,
.dw 3572,15,15,2575,15,15,15,2575,
.dw 3574,15,15,2575,15,15,9028,2575,
.dw 15,15,15,2575,15,15,15,2575,
.dw 15,15,15,2575,15,15,15,2575,
.dw 15,15,15,2575,15,15,15,2575,
.dw 15,15,15,2575,15,15,15,2575,
.dw 15,15,15,2575,15,15,15,2575,
.dw 3190,6372,15,2575,15,15,15,2575,
.dw 15,15,8516,2575,15,15,15,2575,
.dw 15,15,15,2575,15,15,15,2575,
.dw 15,15,15,2575,15,15,15,2575,
.dw 15,15,15,2575,15,15,7572,2575,
.dw 15,15,15,2575,15,15,15,2575,
.dw 15,15,15,2575,15,15,15,2575,
.dw 2518,6740,6740,2575,15,15,15,2575,
.dw 15,15,6372,2575,15,15,15,2575,
.dw 15,15,15,2575,15,15,15,2575,
.dw 15,15,5668,2575,15,15,15,2575,
.dw 2118,8512,15,2575,15,15,15,2575,
.dw 15,15,5060,2575,15,15,15,2575,
.dw 15,15,15,2575,15,15,15,2575,
.dw 15,15,4260,2575,15,15,15,2575,
.dw 15,15,15,2575,15,15,15,2575,
; PATTERN 2:
.dw 7568,1892,15,1024,15,15,15,1039,
.dw 15,3780,15,1031,15,15,15,1039,
.dw 7568,3188,15,1024,15,15,15,1039,
.dw 7568,3780,15,1024,15,15,15,1039,
.dw 15,2516,15,1039,15,15,15,1039,
.dw 15,3188,15,1030,15,15,15,1039,
.dw 15,3780,15,1024,15,15,15,1039,
.dw 15,6372,15,1024,15,15,15,1039,
.dw 15,8516,15,1039,15,15,15,1039,
.dw 15,4260,15,1030,15,15,15,1039,
.dw 8512,3364,15,1024,15,15,15,1039,
.dw 8512,5668,15,1024,15,15,15,1039,
.dw 7568,7572,15,1024,15,15,15,1039,
.dw 15,3780,15,1030,15,15,15,1031,
.dw 7568,3188,15,1024,15,15,15,1039,
.dw 7568,3780,15,1024,15,15,15,1039,
.dw 15,2516,15,1039,15,15,15,1039,
.dw 15,3188,15,1030,15,15,15,1039,
.dw 15,3780,15,1024,15,15,15,1039,
.dw 15,6372,15,1024,15,15,15,1039,
.dw 8512,8516,15,1039,15,15,15,1039,
.dw 15,4260,15,1030,15,15,15,1039,
.dw 8512,3364,15,1024,15,15,15,1039,
.dw 8512,4260,15,1024,15,15,15,-31729,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
; PATTERN 3:
.dw 7568,7572,15,1039,15,15,15,1039,
.dw 7568,3780,15,1030,15,15,15,1039,
.dw 15,3188,15,1024,15,15,15,1039,
.dw 15,3780,15,1024,15,15,15,1039,
.dw 15,5060,3776,1039,15,15,15,1039,
.dw 15,3188,15,1030,15,15,15,1039,
.dw 15,3780,3776,1024,15,15,15,1039,
.dw 15,6372,3184,1024,15,15,15,1039,
.dw 15,8516,3360,1039,15,15,15,1039,
.dw 15,4260,3776,1030,15,15,15,1039,
.dw 8512,3364,4256,1024,15,15,15,1039,
.dw 8512,5668,15,1024,15,15,15,1039,
.dw 4768,9556,3776,1039,15,15,15,1039,
.dw 15,3780,15,1030,15,15,15,1039,
.dw 4768,3188,15,1024,15,15,15,1039,
.dw 4768,2388,15,1024,15,15,15,1039,
.dw 6368,15,15,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 6368,6372,4256,1026,15,15,15,1039,
.dw 6368,6372,15,1039,15,15,15,1039,
.dw 15,15,4256,1026,15,15,15,1039,
.dw 15,15,4768,1039,15,15,15,1039,
.dw 15,6372,5056,1026,15,15,15,1039,
.dw 15,6372,4256,1026,15,15,15,1039,
.dw 15,15,4768,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 5664,5668,4768,1026,15,15,15,1039,
.dw 5664,5668,15,1039,15,15,15,1039,
.dw 7568,15,5056,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 7568,6372,15,1039,15,15,15,1039,
.dw 7568,6372,15,1039,15,15,15,1039,
; PATTERN 4:
.dw 7568,7572,15,1039,15,15,15,1039,
.dw 15,3780,15,1030,15,15,15,1039,
.dw 15,3188,3776,1024,15,15,15,1039,
.dw 15,3780,15,1024,15,15,15,1039,
.dw 15,5060,3776,1039,15,15,15,1039,
.dw 15,3188,15,1030,15,15,15,1039,
.dw 15,3780,3776,1024,15,15,15,1039,
.dw 15,6372,3184,1024,15,15,15,1039,
.dw 4256,8516,3360,1039,15,15,15,1039,
.dw 15,4260,3776,1030,15,15,15,1039,
.dw 4256,3364,4256,1024,15,15,15,1039,
.dw 4256,5668,15,1024,15,15,15,1039,
.dw 4768,9556,3776,1039,15,15,15,1039,
.dw 15,3780,15,1030,15,15,15,1039,
.dw 4768,3188,15,1024,15,15,15,1039,
.dw 4768,2388,15,1024,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,6372,15,1026,15,15,15,1039,
.dw 15,6372,3360,1039,15,15,15,1039,
.dw 6368,15,3184,1026,15,15,15,1039,
.dw 6368,15,15,1039,15,15,15,1039,
.dw 15,5060,3184,1039,15,15,15,1039,
.dw 6368,5060,15,1026,15,15,15,1039,
.dw 5664,15,2832,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 5664,5668,15,1026,15,15,15,1039,
.dw 5664,5668,15,1039,15,15,15,1039,
.dw 8512,15,3360,1026,15,15,15,1039,
.dw 8512,2112,15,1039,15,2836,15,1039,
.dw 15,2112,15,1024,15,2836,15,1039,
.dw 15,2112,3184,1024,15,2836,15,1039,
; PATTERN 5:
.dw 15,15,3360,1039,15,15,15,1039,
.dw 15,15,3776,1039,15,15,15,1039,
.dw 15,2112,4256,1024,15,15,15,1039,
.dw 15,15,3360,1024,15,15,15,-31729,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,4256,1024,15,15,15,1039,
.dw 15,15,3360,1024,15,15,15,-31729,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
; PATTERN 6:
.dw 3184,2516,3184,1039,15,2516,15,1039,
.dw 3184,2516,15,1039,15,2516,15,1039,
.dw 15,2516,3184,1024,15,2516,15,1039,
.dw 3184,2516,15,1024,15,15,15,1039,
.dw 4016,2004,3360,1039,15,2004,15,1039,
.dw 15,2004,15,1030,15,15,15,1039,
.dw 4016,2516,3360,1024,15,2516,15,1039,
.dw 4016,2004,15,1024,15,2004,15,1039,
.dw 3776,1892,3776,1039,15,1892,15,1039,
.dw 3776,1892,15,1030,15,1892,15,1039,
.dw 15,1892,15,1024,15,1892,15,1039,
.dw 15,1892,3184,1024,15,15,15,1039,
.dw 15,2116,3360,1039,15,2116,15,1039,
.dw 15,2116,3776,1030,15,2116,15,1039,
.dw 15,2116,4256,1024,15,2116,15,1039,
.dw 15,15,3360,1024,15,15,15,1039,
.dw 6368,15,3184,1039,15,15,15,1039,
.dw 6368,15,15,1030,15,15,15,1039,
.dw 15,2516,3184,1024,15,15,15,1039,
.dw 6368,2516,15,1024,15,15,15,1039,
.dw 5056,2516,3360,1039,15,2516,15,1039,
.dw 15,2516,15,1030,15,2516,15,1039,
.dw 5056,2388,3360,1024,15,2388,15,1039,
.dw 5056,2004,15,1024,15,2004,15,1039,
.dw 3776,1892,3776,1039,15,1892,15,1039,
.dw 3776,1892,15,1030,15,1892,15,1039,
.dw 15,1892,15,1024,15,1892,15,1039,
.dw 15,15,3184,1024,15,15,15,1039,
.dw 15,2116,3360,1039,15,2116,15,1039,
.dw 15,2116,3776,1030,15,2116,15,1039,
.dw 15,2116,4256,1024,15,2116,15,1039,
.dw 15,15,15,1024,15,15,15,1039,
; PATTERN 7:
.dw 4768,2388,3776,1039,15,2388,15,1039,
.dw 4768,2388,15,1039,15,2388,15,1039,
.dw 15,2388,3776,1024,15,15,15,1039,
.dw 4768,15,15,1024,15,15,15,1039,
.dw 4768,2388,3776,1039,15,2388,15,1039,
.dw 15,2388,15,1030,15,2388,15,1039,
.dw 15,2388,15,1024,15,15,15,1039,
.dw 15,15,15,1024,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,6372,3776,1026,15,15,15,1039,
.dw 15,6372,15,1039,15,15,15,1039,
.dw 6368,15,4256,1026,15,15,15,1039,
.dw 6368,15,4768,1039,15,15,15,1039,
.dw 15,5060,5056,1039,15,15,15,1039,
.dw 6368,5060,4256,1026,15,15,15,1039,
.dw 5664,15,4768,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 5664,5668,4768,1026,15,15,15,1039,
.dw 5664,5668,15,1039,15,15,15,-31729,
.dw 7568,15,5056,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,-31729,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
; PATTERN 8:
.dw 7568,7572,5056,1026,15,15,15,1039,
.dw 15,3780,15,1039,15,15,15,1039,
.dw 7568,3188,15,1024,15,15,15,1039,
.dw 7568,3780,15,1024,15,15,15,1039,
.dw 15,2516,15,1039,15,15,15,1039,
.dw 15,3188,15,1039,15,15,15,1039,
.dw 15,3780,15,1024,15,15,15,1039,
.dw 15,6372,15,1024,15,15,15,1039,
.dw 15,8516,15,1039,15,15,15,1039,
.dw 15,4260,15,1039,15,15,15,1039,
.dw 8512,3364,15,1024,15,15,15,1039,
.dw 8512,5668,15,1024,15,15,15,1039,
.dw 7568,7572,15,1039,15,15,15,1039,
.dw 15,3780,15,1039,15,15,15,1039,
.dw 7568,3188,15,1024,15,15,15,1039,
.dw 7568,3780,15,1024,15,15,15,1039,
.dw 15,5060,15,1039,15,15,15,1039,
.dw 15,3188,15,1039,15,15,15,1039,
.dw 15,3780,15,1024,15,15,15,1039,
.dw 15,6372,15,1024,15,15,15,1039,
.dw 8512,8516,5056,1039,15,15,15,1039,
.dw 15,4260,15,1039,15,15,15,1039,
.dw 8512,3364,4256,1024,15,15,15,1039,
.dw 8512,4260,15,1024,15,15,15,-31729,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
; PATTERN 9:
.dw 4768,15,3776,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 4768,3188,3184,1026,15,15,15,1039,
.dw 4768,3188,15,1026,15,15,15,1039,
.dw 15,15,3184,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,3188,15,1026,15,15,15,1039,
.dw 15,3188,15,1026,15,15,15,1039,
.dw 15,15,4768,1026,15,15,15,1039,
.dw 15,15,2512,1026,15,15,15,1039,
.dw 15,3188,2832,1026,15,15,15,1039,
.dw 15,3188,2384,1026,15,15,15,1039,
.dw 15,15,4256,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 6368,4260,3184,1026,15,15,15,1039,
.dw 6368,4260,15,1026,15,15,15,1039,
.dw 5056,15,3184,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 4256,4260,15,1026,15,15,15,1039,
.dw 15,4260,15,1026,15,15,15,1039,
.dw 15,15,5056,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,4260,3184,1026,15,15,15,1039,
.dw 15,4260,15,1026,15,15,15,-31729,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
; PATTERN 10:
.dw 4768,15,4768,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 8512,2388,4256,1026,15,15,15,1039,
.dw 8512,2388,15,1026,15,15,15,1039,
.dw 6736,15,4256,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 5664,2388,15,1026,15,15,15,1039,
.dw 15,2388,2832,1026,15,15,15,1039,
.dw 4256,15,4256,1026,15,15,15,1039,
.dw 15,15,2832,1026,15,15,15,1039,
.dw 15,2388,3184,1026,15,15,15,1039,
.dw 15,2388,2832,1026,15,15,15,1039,
.dw 3776,15,3184,1026,15,15,15,1039,
.dw 3776,15,15,1026,15,15,15,1039,
.dw 3776,3780,3360,1026,15,15,15,1039,
.dw 15,3780,15,1026,15,15,15,1039,
.dw 5056,15,3776,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 6368,3780,5056,1026,15,15,15,1039,
.dw 15,3780,15,1026,15,15,15,1039,
.dw 7568,15,5056,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,3780,15,1026,15,15,15,1039,
.dw 15,3780,15,1026,15,15,15,1039,
.dw 15,15,6736,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 7568,3780,6368,1026,15,15,15,1039,
.dw 7568,3780,15,1026,15,15,15,-31729,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,3780,15,1039,15,15,15,1039,
.dw 15,3780,15,1039,15,15,15,1039,
; PATTERN 11:
.dw 7136,15,2839,1024,15,15,15,1039,
.dw 15,3572,15,1039,15,15,15,1039,
.dw 5664,1780,15,1024,15,15,15,1039,
.dw 15,2388,15,1024,15,15,15,1039,
.dw 4768,2388,15,1039,15,15,15,1039,
.dw 15,2836,15,1039,15,15,15,1039,
.dw 15,1780,15,1039,15,15,15,1039,
.dw 15,1412,15,1039,15,15,15,1039,
.dw 15,3572,15,1039,15,15,15,1039,
.dw 15,2836,15,1039,15,15,15,1039,
.dw 15,1780,15,1024,15,15,15,1039,
.dw 15,3572,15,1024,15,15,15,1039,
.dw 15,2388,15,1039,15,15,15,1039,
.dw 15,2388,15,1039,15,15,15,1039,
.dw 3568,1412,15,1039,15,15,15,1039,
.dw 3568,1780,15,1039,15,15,15,1039,
.dw 3776,15,3191,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 5056,3188,15,1026,15,15,15,1039,
.dw 15,3188,15,1039,15,15,15,1039,
.dw 6368,15,15,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,3188,15,1039,15,15,15,1039,
.dw 15,3188,15,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,3188,15,1026,15,15,15,1039,
.dw 15,3188,15,1039,15,15,15,1039,
.dw 6368,15,15,1026,6368,15,15,1039,
.dw 6368,15,15,1026,15,15,15,1039,
.dw 6368,3188,3783,1026,15,15,15,1039,
.dw 7568,3188,15,1026,15,15,15,1039,
; PATTERN 12:
.dw 6368,15,3191,1039,15,15,15,1039,
.dw 15,4772,15,1039,15,15,15,1039,
.dw 5056,2388,15,1024,15,15,15,1039,
.dw 15,3188,15,1024,15,15,15,1039,
.dw 4256,1588,15,1039,15,15,15,1039,
.dw 15,4020,15,1039,15,15,15,1039,
.dw 15,2116,15,1024,15,15,15,1039,
.dw 15,2004,15,1024,15,15,15,1039,
.dw 15,4772,2391,1039,15,15,15,1039,
.dw 15,3188,15,1039,15,15,15,1039,
.dw 15,2388,15,1024,15,15,15,1039,
.dw 15,4020,15,1024,15,15,15,1039,
.dw 15,1588,15,1039,15,15,15,1039,
.dw 15,3188,15,1039,15,15,15,1039,
.dw 3184,2004,15,1024,15,15,15,1039,
.dw 3184,2388,15,1039,15,15,15,1039,
.dw 3360,15,2119,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 4256,4260,15,1026,15,15,15,1039,
.dw 15,4260,15,1039,15,15,15,1039,
.dw 5664,15,15,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,4260,15,1039,15,15,15,1039,
.dw 15,4260,15,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,4260,15,1026,15,15,15,1039,
.dw 15,4260,15,1039,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 4256,4260,15,1026,15,15,15,1039,
.dw 4256,4260,15,1039,15,15,15,1039,
; PATTERN 13:
.dw 3776,4772,3776,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 3776,6372,3776,1024,15,15,15,1039,
.dw 3776,3188,3184,1024,15,15,15,1039,
.dw 15,4260,3360,1039,15,15,15,1039,
.dw 15,5668,3776,1039,15,15,15,1039,
.dw 4256,6740,4256,1024,15,15,15,1039,
.dw 4256,3364,15,1024,15,15,15,1039,
.dw 4768,3188,3776,1039,15,15,15,1039,
.dw 4768,6372,15,1039,15,15,15,1039,
.dw 15,3188,15,1024,15,15,15,1039,
.dw 4768,15,15,1024,15,15,15,1039,
.dw 6368,15,15,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 6368,3188,4256,1026,15,15,15,1039,
.dw 6368,3188,15,1026,15,15,15,1039,
.dw 15,15,4256,1026,15,15,15,1039,
.dw 15,15,4768,1026,15,15,15,1039,
.dw 15,3188,5056,1026,15,15,15,1039,
.dw 15,3188,4256,1026,15,15,15,1039,
.dw 5664,15,4768,1026,15,15,15,1039,
.dw 5664,15,15,1026,15,15,15,1039,
.dw 15,2836,4768,1026,15,15,15,1039,
.dw 5664,2836,15,1026,15,15,15,1039,
.dw 7568,15,5056,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 7568,3188,15,1026,15,15,15,1039,
.dw 7568,3188,15,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,-31729,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
; PATTERN 14:
.dw 15,6372,3776,1024,15,15,15,1039,
.dw 15,3188,15,1024,15,15,15,1039,
.dw 15,3780,3776,1039,15,15,15,1039,
.dw 15,5060,15,1030,15,15,15,1039,
.dw 3776,3780,15,1024,15,15,15,1039,
.dw 3776,3780,3184,1024,15,15,15,1039,
.dw 4256,4260,3360,1039,15,15,15,1039,
.dw 4256,2836,3776,1030,15,15,15,1039,
.dw 15,3780,4256,1024,15,15,15,1039,
.dw 4256,2516,15,1024,15,15,15,1039,
.dw 4768,2388,3776,1039,15,15,15,1039,
.dw 15,3188,15,1030,15,15,15,1039,
.dw 4768,3780,15,1024,15,15,15,1039,
.dw 4768,15,15,1024,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,4772,15,1026,15,15,15,1039,
.dw 15,4772,3360,1026,15,15,15,1039,
.dw 6368,15,3184,1026,15,15,15,1039,
.dw 6368,15,15,1026,15,15,15,1039,
.dw 15,5060,3184,1026,15,15,15,1039,
.dw 6368,5060,15,1026,15,15,15,1039,
.dw 5664,15,2832,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 5664,4772,15,1026,15,15,15,1039,
.dw 5664,4772,15,1026,15,15,15,1039,
.dw 8512,2836,3360,1026,15,2838,15,1039,
.dw 8512,2836,15,1026,15,2838,15,1039,
.dw 15,2836,15,1026,15,2838,15,1039,
.dw 15,2836,3184,1039,15,2838,15,1039,
.dw 15,2836,3360,1039,15,15,15,1039,
.dw 15,15,3776,1039,15,15,15,-31729,
; PATTERN 15:
.dw 3184,2516,3184,1039,15,2516,15,1039,
.dw 3184,2516,15,1039,15,2516,15,1039,
.dw 15,2516,3184,1024,15,2516,15,1039,
.dw 3184,2516,15,1024,15,15,15,1039,
.dw 4016,2004,3360,1039,15,2004,15,1039,
.dw 15,2004,15,1039,15,2004,15,1039,
.dw 4016,2004,15,1024,15,2004,15,1039,
.dw 4016,2004,15,1024,15,15,15,1039,
.dw 3776,1892,3776,1039,15,1892,15,1039,
.dw 3776,1892,15,1039,15,1892,15,1039,
.dw 15,1892,15,1024,15,1892,15,1039,
.dw 15,1892,3184,1024,15,15,15,1039,
.dw 15,15,3360,1039,15,15,15,1039,
.dw 15,15,3776,1039,15,15,15,1039,
.dw 15,2116,4256,1024,15,2116,15,1039,
.dw 15,2116,3360,1024,15,2116,15,1039,
.dw 6368,2516,3184,1039,15,2516,15,1039,
.dw 6368,2516,15,1039,15,2516,15,1039,
.dw 15,2516,3184,1024,15,2516,15,1039,
.dw 6368,2516,15,1024,15,15,15,1039,
.dw 5056,2004,3360,1039,15,2004,15,1039,
.dw 15,2004,15,1039,15,2004,15,1039,
.dw 5056,2004,3360,1024,15,2004,15,1039,
.dw 5056,15,15,1024,15,15,15,1039,
.dw 3776,1892,3776,1039,15,1892,15,1039,
.dw 3776,1892,15,1039,15,1892,15,1039,
.dw 15,1892,15,1024,15,1892,15,1039,
.dw 15,1892,3184,1024,15,15,15,1039,
.dw 15,15,3360,1039,15,15,15,1039,
.dw 15,15,3776,1039,15,15,15,1039,
.dw 15,2116,4256,1024,15,2116,15,1039,
.dw 15,2116,15,1024,15,2116,15,1039,
; PATTERN 16:
.dw 4768,2388,3776,1039,15,2388,15,1039,
.dw 4768,2388,15,1039,15,2388,15,1039,
.dw 15,2388,3776,1024,15,2388,15,1039,
.dw 4768,2388,15,1024,15,2388,15,1039,
.dw 4768,1780,3776,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 6368,3188,15,1026,15,15,15,1039,
.dw 6368,15,15,1039,15,15,15,1039,
.dw 15,3188,4256,1026,15,15,15,1039,
.dw 6368,3188,15,1026,15,15,15,1039,
.dw 5664,15,4768,1026,15,15,15,1039,
.dw 15,15,5056,1026,15,15,15,1039,
.dw 5664,2836,4768,1026,15,15,15,1039,
.dw 5664,2836,15,1026,15,15,15,1039,
.dw 7568,15,5056,1026,15,15,15,1039,
.dw 15,7572,15,1039,15,15,15,1039,
.dw 7568,4260,15,1024,15,15,15,1039,
.dw 7568,3780,15,1024,15,15,15,1039,
.dw 15,3364,15,1039,15,15,15,1039,
.dw 15,7572,15,1039,15,15,15,1039,
.dw 15,5668,3776,1024,15,15,15,1039,
.dw 15,2836,15,1024,15,15,15,1039,
.dw 15,2516,3776,1039,15,2516,15,1039,
.dw 15,2516,15,1039,15,2516,15,1039,
.dw 15,2516,15,1024,15,2516,15,1039,
.dw 15,2516,3184,1024,15,2516,15,1039,
.dw 15,2512,3360,1039,15,15,15,1039,
.dw 15,2832,3776,1039,15,15,15,1039,
.dw 4256,15,4256,1024,15,15,15,1039,
.dw 4256,3184,15,1024,15,15,15,1039,
; PATTERN 17:
.dw 4768,3188,3776,1039,15,3188,15,1039,
.dw 4768,3188,15,1039,15,3188,15,1039,
.dw 15,3188,3776,1024,15,3188,15,1039,
.dw 4768,3188,15,1024,15,3188,15,1039,
.dw 4768,3188,3776,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,3184,1026,15,15,15,1039,
.dw 4256,15,2832,1026,15,15,15,1039,
.dw 4256,15,3184,1026,15,15,15,1039,
.dw 15,5668,3360,1026,15,15,15,1039,
.dw 4256,5668,2832,1026,15,15,15,1039,
.dw 4768,15,3184,1026,15,15,15,1039,
.dw 15,15,3776,1026,15,15,15,1039,
.dw 4256,15,3360,1026,15,15,15,1039,
.dw 4256,15,15,1039,15,15,15,1039,
.dw 7568,15,3776,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
; PATTERN 18:
.dw 6368,3184,15,1039,15,15,15,1039,
.dw 15,15,6372,1039,15,15,15,1039,
.dw 5360,15,3188,1039,15,15,15,1039,
.dw 15,3184,4260,1024,15,15,15,1039,
.dw 8512,2672,15,1039,15,15,15,1039,
.dw 15,15,6372,1039,15,15,15,1039,
.dw 15,2112,3188,1024,15,15,15,1039,
.dw 15,15,4260,1039,15,15,15,1039,
.dw 15,2256,15,1039,15,15,15,1039,
.dw 15,15,5668,1039,15,15,15,1039,
.dw 5664,2256,2836,1024,15,15,15,1039,
.dw 15,15,3780,1024,15,15,15,1039,
.dw 15,2832,15,1028,15,15,15,1039,
.dw 15,15,5668,1039,15,15,15,1039,
.dw 3776,15,2836,1024,15,15,15,1039,
.dw 15,15,3780,1039,15,15,15,1039,
.dw 15,4016,15,1028,15,15,15,1039,
.dw 15,15,6372,1039,15,15,15,1039,
.dw 5360,4016,3188,1024,15,15,15,1039,
.dw 15,15,4020,1028,15,15,15,1039,
.dw 8032,4016,15,1039,15,15,15,1039,
.dw 15,15,6372,1039,15,15,15,1039,
.dw 15,15,3188,1024,15,15,15,1039,
.dw 15,15,4020,1039,15,15,15,1039,
.dw 15,4256,15,1024,15,15,15,1039,
.dw 15,15,8516,1039,15,15,15,1039,
.dw 4768,4256,3364,1039,15,15,15,1039,
.dw 8512,15,4260,1024,15,15,15,1039,
.dw 5664,4256,15,1039,15,15,15,1039,
.dw 15,15,8516,1039,15,15,15,1039,
.dw 4256,15,3364,1024,15,15,15,1039,
.dw 15,15,4260,1039,15,15,15,1039,
; PATTERN 19:
.dw 6368,3184,15,1039,15,15,15,1039,
.dw 15,15,6372,1039,15,15,15,1039,
.dw 5360,15,3188,1039,15,15,15,1039,
.dw 15,3184,4260,1024,15,15,15,1039,
.dw 8512,2672,15,1039,15,15,15,1039,
.dw 15,15,6372,1039,15,15,15,1039,
.dw 15,2112,3188,1024,15,15,15,1039,
.dw 15,15,4260,1039,15,15,15,1039,
.dw 15,1888,15,1039,15,15,15,1039,
.dw 15,15,5668,1039,15,15,15,1039,
.dw 5664,1888,2836,1024,15,15,15,1039,
.dw 15,15,3780,1024,15,15,15,1039,
.dw 15,2256,15,1028,15,15,15,1039,
.dw 15,15,5668,1039,15,15,15,1039,
.dw 3776,15,2836,1024,15,15,15,1039,
.dw 15,15,3780,1039,15,15,15,1039,
.dw 15,4768,15,1028,15,15,15,1039,
.dw 15,15,6372,1039,15,15,15,1039,
.dw 5360,4768,3188,1024,15,15,15,1039,
.dw 15,15,4020,1028,15,15,15,1039,
.dw 8032,4768,15,1039,15,15,15,1039,
.dw 15,15,6372,1039,15,15,15,1039,
.dw 15,4768,3188,1024,15,15,15,1039,
.dw 15,15,4020,1039,15,15,15,1039,
.dw 15,4256,15,1028,15,15,15,1039,
.dw 15,15,8516,1039,15,15,15,1039,
.dw 4768,15,3364,1039,15,15,15,1039,
.dw 8512,15,4260,1024,15,15,15,1039,
.dw 5664,15,15,1039,15,15,15,1039,
.dw 15,15,8516,1039,15,15,15,1039,
.dw 4256,15,3364,1024,15,15,15,1039,
.dw 15,15,4260,1039,15,15,15,1039,
; PATTERN 20:
.dw 6368,3184,15,1039,15,15,15,1039,
.dw 15,15,6372,1039,15,15,15,1039,
.dw 5360,15,3188,1039,15,15,15,1039,
.dw 15,3184,4260,1024,15,15,15,1039,
.dw 8512,2672,15,1039,15,15,15,1039,
.dw 15,15,6372,1039,15,15,15,1039,
.dw 15,2112,3188,1024,15,15,15,1039,
.dw 15,15,4260,1039,15,15,15,1039,
.dw 15,2256,15,1039,15,15,15,1039,
.dw 15,15,5668,1039,15,15,15,1039,
.dw 5664,2256,2836,1024,15,15,15,1039,
.dw 15,15,3780,1024,15,15,15,1039,
.dw 15,2832,15,1028,15,15,15,1039,
.dw 15,15,5668,1039,15,15,15,1039,
.dw 3776,15,2836,1024,15,15,15,1039,
.dw 15,15,3780,1039,15,15,15,1039,
.dw 15,4768,15,1026,15,15,15,1039,
.dw 15,15,6372,1039,15,15,15,1039,
.dw 5360,4768,3188,1024,15,15,15,1039,
.dw 15,15,4020,1026,15,15,15,1039,
.dw 8032,4768,15,1039,15,15,15,1039,
.dw 15,15,6372,1039,15,15,15,1039,
.dw 15,5360,3188,1024,15,15,15,1039,
.dw 15,15,4020,1039,15,15,15,1039,
.dw 15,6368,15,1026,15,15,15,1039,
.dw 15,15,6372,1039,15,15,15,1039,
.dw 4768,15,3188,1039,15,15,15,1039,
.dw 8512,6368,4260,1024,15,15,15,1039,
.dw 5664,6368,15,1039,15,15,15,1039,
.dw 15,15,6372,1039,15,15,15,1039,
.dw 4256,15,3188,1024,15,15,15,1039,
.dw 15,15,4260,1039,15,15,15,1039,
; PATTERN 21:
.dw 4016,3184,15,1039,15,15,15,1039,
.dw 15,15,6372,1039,15,15,15,1039,
.dw 15,3184,3188,1039,15,15,15,1039,
.dw 15,15,4260,1026,15,15,4775,1039,
.dw 5360,2832,15,1024,15,15,15,1039,
.dw 15,15,6372,1039,15,15,15,1039,
.dw 4016,2672,3188,1039,15,15,15,1039,
.dw 15,15,4260,1039,15,15,15,1039,
.dw 15,2832,15,1026,15,15,15,1039,
.dw 15,15,5668,1039,15,15,15,1039,
.dw 15,3360,2836,1024,15,15,15,1039,
.dw 15,15,3780,1024,15,15,15,1039,
.dw 5664,4256,15,1024,15,15,15,1039,
.dw 15,15,5668,1039,15,15,15,1039,
.dw 4256,4256,2836,1024,15,15,15,1039,
.dw 15,15,3780,1039,15,15,15,1039,
.dw 9552,4768,15,1039,15,15,15,1039,
.dw 15,15,8036,1039,15,15,15,1039,
.dw 9552,15,4020,1024,15,15,15,1039,
.dw 9552,4768,8036,1024,15,15,15,1039,
.dw 6368,4256,15,1039,15,15,15,1039,
.dw 15,15,8036,1039,15,15,15,1039,
.dw 9552,4016,4020,1024,15,15,15,1039,
.dw 15,15,4020,1039,15,15,15,1039,
.dw 8512,4256,15,1039,15,15,15,1039,
.dw 15,15,8516,1039,15,15,15,1039,
.dw 15,15,3364,1024,15,15,15,1039,
.dw 8512,15,4260,1024,15,15,15,1039,
.dw 5664,4256,15,1039,15,15,15,1039,
.dw 15,15,8516,1039,15,15,15,1039,
.dw 8512,15,3364,1024,15,15,15,1039,
.dw 15,4256,4260,1039,15,15,15,1039,
; PATTERN 22:
.dw 15,4768,15,1028,15,15,15,1039,
.dw 15,15,9556,1039,15,15,15,1039,
.dw 4768,15,4772,1039,15,15,15,1039,
.dw 4768,4768,4772,1024,15,15,15,1039,
.dw 4016,4256,15,1024,15,15,15,1039,
.dw 15,15,9556,1039,15,15,15,1039,
.dw 4768,4016,4772,1039,15,15,15,1039,
.dw 15,15,4772,1039,15,15,15,1039,
.dw 15,4256,15,1028,15,15,15,1039,
.dw 15,15,8516,1039,15,15,15,1039,
.dw 5664,15,4260,1039,15,15,15,1039,
.dw 15,15,4260,1024,15,15,15,1039,
.dw 4256,4256,15,1028,15,15,15,1039,
.dw 15,4768,8516,1039,15,15,15,1039,
.dw 15,5360,4020,1024,15,15,15,1039,
.dw 15,5664,4260,1039,15,15,15,1039,
.dw 4768,6368,15,1028,15,15,15,1039,
.dw 15,15,6372,1039,15,15,15,1039,
.dw 4256,15,3188,1024,15,15,15,1039,
.dw 15,15,4260,1024,15,15,15,1039,
.dw 3184,15,15,1039,15,15,15,1039,
.dw 15,15,6372,1039,15,15,15,1039,
.dw 15,6368,3188,1024,15,15,15,1039,
.dw 15,4256,4260,1039,15,15,15,1039,
.dw 4016,3184,15,1039,15,15,15,1039,
.dw 4016,15,6372,1039,15,15,15,1039,
.dw 15,3184,3188,1024,15,15,15,1039,
.dw 4016,15,4260,1024,15,15,15,1039,
.dw 4256,3360,15,1039,15,15,15,1039,
.dw 15,15,6372,1039,15,15,15,1039,
.dw 15,3360,3188,1024,15,15,15,1039,
.dw 15,15,4260,1039,15,15,15,1039,
; PATTERN 23:
.dw 6368,3184,15,1039,15,15,15,1039,
.dw 15,15,6372,1039,15,15,15,1039,
.dw 4256,15,3188,1024,15,15,15,1039,
.dw 15,15,4260,1024,15,15,4775,1039,
.dw 3184,15,15,1039,15,15,15,1039,
.dw 15,15,6372,1039,15,15,15,1039,
.dw 15,15,3188,1024,15,15,15,1039,
.dw 15,15,4260,1039,15,15,15,1039,
.dw 3184,15,15,1039,15,15,15,1039,
.dw 15,15,6372,1039,15,15,15,1039,
.dw 15,3184,3188,1024,15,15,15,1039,
.dw 3184,15,4260,1024,15,15,15,1039,
.dw 4256,15,15,1039,15,15,15,1039,
.dw 15,3184,6372,1039,15,15,15,1039,
.dw 5360,15,3188,1024,15,15,15,1039,
.dw 15,15,4260,1039,15,15,15,1039,
.dw 6368,3184,15,1039,15,15,15,1039,
.dw 15,15,6372,1039,15,15,15,1039,
.dw 4256,15,3188,1024,15,15,15,1039,
.dw 15,3184,4260,1024,15,15,15,1039,
.dw 3184,15,15,1039,15,15,15,1039,
.dw 15,15,6372,1039,15,15,15,1039,
.dw 15,15,3188,1024,15,15,15,1039,
.dw 15,15,4260,1039,15,15,15,1039,
.dw 3184,15,15,1039,15,15,15,1039,
.dw 15,15,6372,1039,15,15,15,1039,
.dw 15,3184,3188,1024,15,15,15,1039,
.dw 3184,15,4260,1024,15,15,15,1039,
.dw 4256,15,15,1039,15,15,15,1039,
.dw 15,3184,6372,1039,15,15,15,1039,
.dw 5360,15,3188,1024,15,15,15,1039,
.dw 15,15,4260,1039,15,15,15,1039,
; PATTERN 24:
.dw 6368,3184,15,1039,15,15,15,1039,
.dw 15,15,6370,1039,15,15,15,1039,
.dw 3184,15,3188,1039,15,15,15,1039,
.dw 15,3184,4262,1039,15,15,15,1039,
.dw 4256,3184,15,1039,15,15,15,1039,
.dw 15,15,6375,1039,15,15,15,1039,
.dw 5360,15,3191,1039,15,15,15,1039,
.dw 15,15,4271,1039,15,15,15,1039,
.dw 6368,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,271,15,15,15,271,
.dw 15,15,15,271,15,15,15,271,
.dw 15,15,15,271,15,15,15,271,
.dw 15,15,15,271,15,15,15,271,
.dw 15,15,15,271,15,15,15,271,
.dw 15,15,15,271,15,15,15,271,
.dw 15,15,15,271,15,15,15,271,
.dw 15,15,15,271,15,15,15,271,
.dw 15,15,15,271,15,15,15,271,
.dw 15,15,15,271,15,15,15,271,
.dw 15,15,15,271,15,15,15,271,
.dw 15,15,15,271,15,15,15,271,
.dw 15,15,15,271,15,15,15,271,
.dw 15,15,15,271,15,15,15,271,
.dw 15,15,15,271,15,15,15,271,
; PATTERN 25:
.dw 7136,3568,7136,1024,15,15,15,1039,
.dw 15,4772,15,1039,15,15,15,1039,
.dw 3568,2388,7136,1024,15,15,15,1039,
.dw 3568,3568,3568,1024,15,15,15,1039,
.dw 15,2388,15,1026,15,15,15,1039,
.dw 15,3568,7136,1024,15,15,15,1039,
.dw 15,3568,3568,1026,15,15,15,1039,
.dw 15,4774,15,1039,15,15,4774,1039,
.dw 7136,3568,3188,1039,15,15,4258,1039,
.dw 3568,3568,4768,1024,15,15,15,1039,
.dw 15,4768,15,1039,15,15,15,1039,
.dw 7136,15,15,1039,15,15,15,1039,
.dw 7568,3568,7568,1024,15,15,15,1039,
.dw 15,4772,15,1039,15,15,15,1039,
.dw 3776,2388,7568,1039,15,15,15,1039,
.dw 3776,3568,3776,1039,15,15,15,1039,
.dw 15,2388,15,1039,15,15,15,1039,
.dw 15,3568,7568,1039,15,15,15,1039,
.dw 15,3568,3776,1039,15,15,15,1039,
.dw 15,4774,15,1039,15,15,15,1039,
.dw 7568,3568,3184,1039,15,15,3190,1039,
.dw 3776,3568,3188,1039,15,15,3186,1039,
.dw 15,4768,3776,1039,15,15,5056,1039,
.dw 7568,6368,7136,1039,15,15,15,-31729,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
; PATTERN 26:
.dw 4768,2000,9552,1796,15,15,15,1807,
.dw 15,15,9552,1796,6368,2000,4768,1796,
.dw 4768,15,15,1807,4256,2000,4768,1796,
.dw 4016,2000,8032,1807,15,15,15,1807,
.dw 15,15,15,1796,4256,2000,6368,1796,
.dw 15,15,15,1807,15,2000,15,1796,
.dw 4768,2000,15,1807,15,15,15,1807,
.dw 15,15,7136,1796,6368,2000,3568,1796,
.dw 4768,15,15,1807,4016,2000,3568,1796,
.dw 3184,2000,6000,1807,15,15,15,1807,
.dw 15,15,15,1796,3568,2000,4768,1796,
.dw 15,15,15,1807,15,2000,15,1796,
.dw 4016,2000,15,1807,15,15,15,1807,
.dw 15,15,9552,1796,15,2000,4768,1796,
.dw 15,15,15,1807,15,2000,4768,1796,
.dw 3184,2000,8032,1807,15,15,15,1807,
.dw 15,15,15,1796,15,2000,6368,1796,
.dw 15,15,15,1807,4768,2000,15,1796,
.dw 4512,2000,15,1807,15,15,15,1807,
.dw 4016,15,9024,1796,3568,2000,4512,1796,
.dw 15,15,15,1807,2512,2000,4512,1796,
.dw 15,2000,7136,1807,15,15,15,1807,
.dw 15,15,15,1796,15,2000,6000,1796,
.dw 15,15,15,1807,15,2000,15,-30972,
.dw 15,2000,15,-30961,15,15,15,-30961,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
; PATTERN 27:
.dw 4768,2000,15,1807,15,15,15,1807,
.dw 15,15,9552,1796,6368,2000,4768,1796,
.dw 4768,15,15,1807,4256,2000,4768,1796,
.dw 4016,2000,8032,1807,15,15,15,1807,
.dw 15,15,15,1796,4256,2000,6368,1796,
.dw 15,15,15,1807,15,2000,15,1796,
.dw 4768,2000,15,1807,15,15,15,1807,
.dw 15,15,6000,1796,6368,2000,15,1796,
.dw 4768,15,15,1807,4016,2000,3360,1796,
.dw 3184,2000,15,1807,15,15,15,1807,
.dw 15,15,3568,1796,3568,2000,4016,1796,
.dw 15,15,15,1807,15,2000,15,1796,
.dw 4016,2000,15,1807,15,15,15,1807,
.dw 3184,15,6368,1796,15,2000,15,1796,
.dw 15,15,15,1807,15,2000,6368,1796,
.dw 2384,2000,15,1807,15,15,15,1807,
.dw 2000,15,6368,1796,15,2000,15,1796,
.dw 15,15,15,1807,15,2000,15,-30972,
.dw 2384,2000,15,-30961,15,15,15,1807,
.dw 15,15,4768,-30972,15,2000,4768,-30972,
.dw 15,15,15,1807,15,2000,15,1796,
.dw 15,2000,15,1807,15,15,15,1807,
.dw 15,15,15,1796,15,2000,15,1796,
.dw 15,15,15,1807,15,2000,15,1796,
.dw 15,2000,15,-30961,15,15,15,-30961,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
; PATTERN 28:
.dw 2384,2000,15,1792,15,15,15,1807,
.dw 15,15,4768,1792,15,2000,8032,1792,
.dw 15,15,15,1807,15,2000,8032,1792,
.dw 15,2000,6368,1792,15,15,15,1807,
.dw 15,15,15,1792,4770,2000,4768,1792,
.dw 15,15,15,1807,4770,2000,15,1792,
.dw 15,2000,15,1792,15,15,15,1807,
.dw 15,15,6000,1792,15,2000,15,1792,
.dw 15,15,15,1807,15,2000,6000,1792,
.dw 15,2000,8032,1792,15,15,15,1807,
.dw 15,15,15,1792,15,2000,6000,1792,
.dw 15,15,15,1807,15,2000,15,1792,
.dw 15,2000,15,1792,15,15,15,1807,
.dw 15,15,9552,1792,15,2000,15,1792,
.dw 15,15,15,1807,15,2000,9552,1792,
.dw 15,2000,8032,1792,15,15,15,1807,
.dw 15,15,15,1792,4770,2000,6368,1792,
.dw 15,15,15,1807,4770,2000,15,1792,
.dw 15,2000,15,1792,15,15,15,1807,
.dw 15,15,15,1792,15,2000,6000,1792,
.dw 15,15,15,1807,15,2000,6000,1792,
.dw 15,2000,8032,1792,15,15,15,1807,
.dw 15,15,15,1792,15,2000,6000,1792,
.dw 15,15,15,1807,15,2000,15,-30976,
.dw 15,2000,15,1792,15,15,15,1807,
.dw 15,15,15,-30961,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
; PATTERN 29:
.dw 15,2000,15,1792,15,15,15,1807,
.dw 15,15,9552,1792,15,2000,15,1792,
.dw 15,15,15,1807,15,2000,9552,1792,
.dw 15,2000,8032,1792,15,15,15,1807,
.dw 15,15,15,1792,4770,2000,6368,1792,
.dw 15,15,15,1807,3362,2000,15,1792,
.dw 15,2000,15,1792,15,15,15,1807,
.dw 15,15,6000,1792,15,2000,15,1792,
.dw 15,15,15,1807,15,2000,6000,1792,
.dw 15,2000,8032,1792,15,15,15,1807,
.dw 15,15,15,1792,15,2000,9552,1792,
.dw 15,15,15,1807,3362,2000,15,1792,
.dw 3186,2000,15,1792,15,15,15,1807,
.dw 15,15,15,1792,15,2000,6368,1792,
.dw 15,15,15,1807,15,2000,6368,1792,
.dw 3186,2000,8032,1792,15,15,15,1807,
.dw 15,15,15,1792,4016,2000,9552,1792,
.dw 15,15,15,1807,4256,2000,15,1792,
.dw 15,2000,15,1792,15,15,15,1807,
.dw 15,15,6368,1792,15,2000,15,1792,
.dw 15,15,15,1807,15,2000,6368,1792,
.dw 15,2000,8512,1792,15,15,15,1807,
.dw 15,15,15,1792,15,2000,6368,1792,
.dw 15,15,15,1807,15,2000,15,1792,
.dw 15,2000,15,1792,15,15,15,1807,
.dw 15,15,15,-30976,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
; PATTERN 30:
.dw 4772,2000,9552,1792,15,15,15,1807,
.dw 15,2004,15,1807,15,15,15,1807,
.dw 15,2006,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,-30961,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.org $8000
.end
